@@ -90,6 +90,8 @@ def _get_cmap_lightness_rank(cmap):
         For diverging colormaps, this is the max RMSE of either half.
     name : str
         The name of `cmap`.
+        For qualitative and miscellaneous colormaps, this is the only value
+        that is used.
 
     """
 
@@ -110,17 +112,9 @@ def _get_cmap_lightness_rank(cmap):
     # Set lightness profile type to 0
     L_type = 0
 
-    # Determine the RMSE of the lightness profile
-    if get_cmap_type(cmap) in ('diverging', 'cyclic'):
-        # If cmap is diverging, calculate RMSE of both halves
-        central_i = [int(np.floor(cmap.N/2)), int(np.ceil(cmap.N/2))]
-        L_rmse = np.max([np.around(np.std(derivs[:central_i[0]]), 1),
-                         np.around(np.std(derivs[central_i[1]:]), 1)])
-
-        # Calculate central lightness value
-        L_start = np.around(np.average(L[central_i]), 1)
-    else:
-        # Else, take RMSE of entire lightness profile
+    # Determine the RMSE of the lightness profile of a sequential colormap
+    if(get_cmap_type(cmap) == 'sequential'):
+        # Take RMSE of entire lightness profile
         L_rmse = np.around(np.std(derivs), 1)
 
         # Calculate starting lightness value
@@ -130,19 +124,35 @@ def _get_cmap_lightness_rank(cmap):
         L_type += ~(np.sum(rgb[0]) == 0)*2
         L_type += ((np.sum(rgb[0]) == 0) == (np.sum(rgb[-1]) == 3))
 
-    # Determine range
-    L_min = np.around(np.min(L), 1)
-    L_max = np.around(np.max(L), 1)
-    L_rng = np.around(np.abs(L_max-L_min), 1)
+    # Diverging/cyclic colormaps
+    elif get_cmap_type(cmap) in ('diverging', 'cyclic'):
+        # Calculate RMSE of both halves
+        central_i = [int(np.floor(cmap.N/2)), int(np.ceil(cmap.N/2))]
+        L_rmse = np.max([np.around(np.std(derivs[:central_i[0]]), 1),
+                         np.around(np.std(derivs[central_i[1]:]), 1)])
 
-    # Return contributions to the rank
+        # Calculate central lightness value
+        L_start = np.around(np.average(L[central_i]), 1)
+
+    # Determine lightness range for sequential/diverging/cyclic colormaps
+    if get_cmap_type(cmap) in ('sequential', 'diverging', 'cyclic'):
+        L_min = np.around(np.min(L), 1)
+        L_max = np.around(np.max(L), 1)
+        L_rng = np.around(np.abs(L_max-L_min), 1)
+
+    # For qualitative/misc colormaps, set all lightness values to zero
+    else:
+        L_type = L_start = L_rng = L_rmse = 0
+
+    # Return lightness contributions to the rank
     return(L_type, L_start, L_rng, L_rmse, cmap.name)
 
 
 # %% FUNCTIONS
 # This function creates an overview plot of all colormaps specified
 def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
-                         sort='alphabetical', plot_profile=False):
+                         sort='alphabetical', plot_profile=False,
+                         title="Colormap Overview"):
     """
     Creates an overview plot containing all colormaps defined in the provided
     `cmaps`.
@@ -161,18 +171,27 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
         Whether all colormaps in `cmaps` should be categorized into their
         colormap types (sequential; diverging; cyclic; qualitative; misc).
         If `cmaps` is a dict, this value is ignored.
-    sort : {'alphabetical'/'name'; 'lightness'}. Default: 'alphabetical'
-        String indicating how the colormaps should be sorted in the overview.
+    sort : {'alphabetical'/'name'; 'lightness'}, function or None. Default: \
+        'alphabetical'
+        String or function indicating how the colormaps should be sorted in the
+        overview.
         If 'alphabetical', the colormaps are sorted alphabetically on their
         name.
         If 'lightness', the colormaps are sorted on their starting lightness
         and their lightness range.
+        If function, a function definition that takes a
+        :obj:`~matplotlib.colors.Colormap` object and returns the sorted
+        position of that colormap.
+        If *None*, the colormaps retain the order they were given in.
     plot_profile : bool or float. Default: False
         Whether the lightness profiles of all colormaps should be plotted. If
         not *False*, the lightness profile of a colormap is plotted on top of
         its gray-scale version and `plot_profile` is used for setting the alpha
         (opacity) value.
         If `plot_profile` is *True*, it will be set to `0.25`.
+    title : str or False. Default: "Colormap Overview"
+        String to be used as the title of the colormap overview.
+        If empty or *False*, no title will be used.
 
     Notes
     -----
@@ -180,7 +199,7 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
     :mod:`matplotlib.cm`, or their corresponding
     :obj:`~matplotlib.colors.Colormap` object.
     Any provided reversed colormaps (colormaps that end their name with '_r')
-    are ignored.
+    are ignored if their normal versions were provided as well.
 
     If `plot_profile` is not set to *False*, the lightness profiles are plotted
     on top of the gray-scale colormap versions, where the y-axis ranges from 0%
@@ -197,6 +216,18 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
     if cmaps is None:
         cmaps = cmrcm.cmap_d.values()
 
+    # If sort is a string, obtain proper function
+    if isinstance(sort, string_types):
+        # Convert sort to lowercase
+        sort = sort.lower()
+
+        # Check what string was provided and obtain sorting function
+        if sort in ('alphabetical', 'name'):
+            def sort(x):
+                return(x.name)
+        elif(sort == 'lightness'):
+            sort = _get_cmap_lightness_rank
+
     # Create empty list of cmaps
     cmaps_list = []
 
@@ -219,9 +250,8 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
             # Loop over all cmaps and remove reversed versions
             for cmap in cmaps:
                 if isinstance(cmap, string_types):
-                    if not cmap.endswith('_r'):
-                        cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
-                elif not cmap.name.endswith('_r'):
+                    cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
+                else:
                     cmaps_dict[cm_type].append(cmap)
 
     # Else, it is a list with no cm_types
@@ -237,17 +267,15 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
             for cmap in cmaps:
                 cm_type = get_cmap_type(cmap)
                 if isinstance(cmap, string_types):
-                    if not cmap.endswith('_r'):
-                        cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
-                elif not cmap.name.endswith('_r'):
+                    cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
+                else:
                     cmaps_dict[cm_type].append(cmap)
         else:
             # Loop over all cmaps and remove reversed versions
             for cmap in cmaps:
                 if isinstance(cmap, string_types):
-                    if not cmap.endswith('_r'):
-                        cmaps_list.append(mplcm.get_cmap(cmap))
-                elif not cmap.name.endswith('_r'):
+                    cmaps_list.append(mplcm.get_cmap(cmap))
+                else:
                     cmaps_list.append(cmap)
 
     # If use_types is True, a dict is currently used
@@ -256,13 +284,18 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
         for key, value in cmaps_dict.items():
             # If this cm_type has at least 1 colormap, sort and add them
             if value:
-                # Sort on lightness if requested and this cm_type is compatible
-                if((sort.lower() == 'lightness') and
-                   (key not in ('qualitative', 'misc'))):
-                    value.sort(key=_get_cmap_lightness_rank)
-                # Else, sort on name
-                else:
-                    value.sort(key=lambda x: x.name)
+                # Obtain the names of all colormaps
+                names = [x.name for x in value]
+
+                # Remove all reversed colormaps that also have their original
+                off_dex = len(names)-1
+                for i, name in enumerate(reversed(names)):
+                    if name.endswith('_r') and name[:-2] in names:
+                        value.pop(off_dex-i)
+
+                # Sort the colormaps if requested
+                if sort is not None:
+                    value.sort(key=sort)
 
                 # Add to list
                 cmaps_list.append(key)
@@ -270,22 +303,33 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
 
     # Else, a list is used
     else:
-        # Sort the colormaps
-        if(sort.lower() == 'lightness'):
-            cmaps_list.sort(key=_get_cmap_lightness_rank)
-        else:
-            cmaps_list.sort(key=lambda x: x.name)
+        # Obtain the names of all colormaps
+        names = [x.name for x in cmaps_list]
+
+        # Remove all reversed colormaps that also have their original
+        off_dex = len(names)-1
+        for i, name in enumerate(reversed(names)):
+            if name.endswith('_r') and name[:-2] in names:
+                cmaps_list.pop(off_dex-i)
+
+        # Sort the colormaps if requested
+        if sort is not None:
+            cmaps_list.sort(key=sort)
 
     # Obtain the colorspace converter for showing cmaps in grey-scale
     cspace_convert = cspace_converter("sRGB1", "CAM02-UCS")
 
     # Create figure instance
-    height = 0.4*(len(cmaps_list)+1)
-    fig, axes = plt.subplots(figsize=(6.4, height),
-                             nrows=len(cmaps_list), ncols=2)
-    fig.subplots_adjust(top=(1-0.24/height), bottom=0.048/height, left=0.2,
-                        right=0.99, wspace=0.05)
-    fig.suptitle("Colormap Overview", fontsize=16, y=1.0, x=0.595)
+    height = 0.4*(len(cmaps_list)+bool(title))
+    fig, axes = plt.subplots(figsize=(6.4, height), nrows=len(cmaps_list),
+                             ncols=2)
+    if title:
+        fig.subplots_adjust(top=(1-0.288/height), bottom=0.048/height,
+                            left=0.2, right=0.99, wspace=0.05)
+        fig.suptitle(title, fontsize=16, x=0.595, y=1.0-0.048/height)
+    else:
+        fig.subplots_adjust(top=(1-0.048/height), bottom=0.048/height,
+                            left=0.2, right=0.99, wspace=0.05)
 
     # If cmaps_list only has a single element, make sure axes is a list
     if(len(cmaps_list) == 1):
